==> jc-1.4.0.tar.gz: soot/jimple/internal/JUshrExpr.h <==
// public class soot.jimple.internal.JUshrExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr
// @dep_class 2edcd395b8ec24b3 soot_jimple_internal_AbstractJimpleIntLongBinopExpr
// @dep_class f7daa7456ac2b99b soot_jimple_internal_JUshrExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractJimpleIntLongBinopExpr

#include "soot/jimple/internal/AbstractJimpleIntLongBinopExpr.h"

#ifndef _JC_soot_jimple_internal_JUshrExpr_H_
#define _JC_soot_jimple_internal_JUshrExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JUshrExpr$sub_refs	_jc_soot_jimple_internal_JUshrExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JUshrExpr$sub_nonrefs	_jc_soot_jimple_internal_JUshrExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JUshrExpr$refs	_jc_soot_jimple_internal_JUshrExpr$refs;
typedef struct _jc_soot_jimple_internal_JUshrExpr$nonrefs	_jc_soot_jimple_internal_JUshrExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JUshrExpr$object	_jc_soot_jimple_internal_JUshrExpr$object;

typedef const struct _jc_soot_jimple_internal_JUshrExpr$vmethods	_jc_soot_jimple_internal_JUshrExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JUshrExpr$vtable	_jc_soot_jimple_internal_JUshrExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JUshrExpr$vtype	_jc_soot_jimple_internal_JUshrExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JUshrExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_internal_JUshrExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JUshrExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JUshrExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JUshrExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JUshrExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JUshrExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JUshrExpr$method_info$getSymbol$ce407d9fb7da8b41;
extern _jc_method _jc_soot_jimple_internal_JUshrExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_JUshrExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *);
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *);
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JUshrExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
	_jc_soot_jimple_internal_JUshrExpr$vmethods	soot_jimple_internal_JUshrExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JUshrExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JUshrExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JUshrExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JUshrExpr$refs {
    _jc_soot_jimple_internal_JUshrExpr$sub_refs	soot_jimple_internal_JUshrExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JUshrExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JUshrExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_JUshrExpr$sub_nonrefs	soot_jimple_internal_JUshrExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JUshrExpr$object {
	_jc_soot_jimple_internal_JUshrExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JUshrExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JUshrExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JUshrExpr$vtype _jc_soot_jimple_internal_JUshrExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JUshrExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JUshrExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JUshrExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JUshrExpr.h <==
// public class soot.jimple.internal.JUshrExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr
// @dep_class 2edcd395b8ec24b3 soot_jimple_internal_AbstractJimpleIntLongBinopExpr
// @dep_class f7daa7456ac2b99b soot_jimple_internal_JUshrExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractJimpleIntLongBinopExpr

#include "soot/jimple/internal/AbstractJimpleIntLongBinopExpr.h"

#ifndef _JC_soot_jimple_internal_JUshrExpr_H_
#define _JC_soot_jimple_internal_JUshrExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JUshrExpr$sub_refs	_jc_soot_jimple_internal_JUshrExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JUshrExpr$sub_nonrefs	_jc_soot_jimple_internal_JUshrExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JUshrExpr$refs	_jc_soot_jimple_internal_JUshrExpr$refs;
typedef struct _jc_soot_jimple_internal_JUshrExpr$nonrefs	_jc_soot_jimple_internal_JUshrExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JUshrExpr$object	_jc_soot_jimple_internal_JUshrExpr$object;

typedef const struct _jc_soot_jimple_internal_JUshrExpr$vmethods	_jc_soot_jimple_internal_JUshrExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JUshrExpr$vtable	_jc_soot_jimple_internal_JUshrExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JUshrExpr$vtype	_jc_soot_jimple_internal_JUshrExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JUshrExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_JUshrExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JUshrExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JUshrExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JUshrExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JUshrExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JUshrExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JUshrExpr$method_info$getSymbol$ce407d9fb7da8b41;
extern _jc_method _jc_soot_jimple_internal_JUshrExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_JUshrExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_JUshrExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JUshrExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
	_jc_soot_jimple_internal_JUshrExpr$vmethods	soot_jimple_internal_JUshrExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JUshrExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JUshrExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JUshrExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JUshrExpr$refs {
    _jc_soot_jimple_internal_JUshrExpr$sub_refs	soot_jimple_internal_JUshrExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JUshrExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JUshrExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntLongBinopExpr;
    _jc_soot_jimple_internal_JUshrExpr$sub_nonrefs	soot_jimple_internal_JUshrExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JUshrExpr$object {
	_jc_soot_jimple_internal_JUshrExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JUshrExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JUshrExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JUshrExpr$vtype _jc_soot_jimple_internal_JUshrExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JUshrExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JUshrExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JUshrExpr_H_ */
